#!/usr/bin/webif-page
<?

###
 #
 # FreeWLAN Addons - http://www.freewlan.info
 #
 # This Script is based on the original La Fonera Firmware version 0.7.1r2
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 # MA  02110-1301, USA
 #
 # http://www.gnu.org/copyleft/gpl.html
 #
###

. /usr/lib/webif/webif.sh

validate <<EOF
string|FORM_submit|@TR<<Submit>>|max=10|$FORM_submit
EOF

if [ "$?" != "0" ]
then
	FORM_submit=""
fi

load_settings fon
get_default mode wan mode

if empty "$FORM_submit"; then
	get_default ssid private essid
	get_default hide_ssid private hidden
	get_default enc private encryption
	get_default crypto private wpa_crypto
	get_default bridge wan bridge
	get_default bgmode advanced bgmode
	get_default channel advanced channel
	case "${FORM_enc##/*}" in
		wep|WEP) FORM_auth=wep;;
		WPA|WPA1|wpa|wpa1) FORM_auth=wpa;;
		WPA2|wpa2) FORM_auth=wpa2;;
		mixed|Mixed) FORM_auth=mixed;;
		*) FORM_auth=open;;
	esac
	case "${FORM_crypto}" in
		aes|AES|ccmp|CCMP) FORM_crypto="aes";;
		tkip|TKIP) FORM_crypto="tkip";;
		tkip+aes|TKIP+AES|aes+tkip|AES+TKIP) FORM_crypto="tkip+aes";;
		*) FORM_crypto=tkip+aes;;
	esac
	get_default psk private password
	get_default wepkey private wepkey
	get_default key1 private key1
	get_default key2 private key2
	get_default key3 private key3
	get_default key4 private key4
	get_default txp private txpower
else
	validate <<EOF
	string|FORM_ssid|@TR<<ESSID>>|required max=28|$FORM_ssid
	bool|FORM_hide_ssid|@TR<<Hide SSID>>|required|$FORM_hide_ssid
	chk_auth|FORM_auth|@TR<<Authentication>>||$FORM_auth
	int|FORM_wepkey|@TR<<Selected WEP Key>>|min=1 max=4|$FORM_wepkey
	chk_crypto|FORM_crypto|@TR<<Cipher>>||$FORM_crypto
EOF
equal "$?" 0 && {
	case "$FORM_auth" in
		wpa|wpa2|mixed)
			V_PSK="required"
		;;
		wep)
			eval "V_K$FORM_wepkey=required"
		;;
	esac

	validate <<EOF
	string|FORM_psk|@TR<<WPA Passphrase>>|min=8 max=63 $V_PSK|$FORM_psk
	wep|FORM_key1|@TR<<WEP Key>> 1|$V_K1|$FORM_key1
	wep|FORM_key2|@TR<<WEP Key>> 2|$V_K2|$FORM_key2
	wep|FORM_key3|@TR<<WEP Key>> 3|$V_K3|$FORM_key3
	wep|FORM_key4|@TR<<WEP Key>> 4|$V_K4|$FORM_key4
EOF
	equal "$?" 0 && {
		save_setting fon private essid "$FORM_ssid"
		save_setting fon private hidden "$FORM_hide_ssid"
		save_setting fon wan bridge "$FORM_bridge"
		if [ "$FORM_bridge" = "1" ]; then
			save_setting remote method webif "1"
		fi
		save_setting fon private txpower "$FORM_txp"
		case "$FORM_auth" in
			wpa|wpa2|mixed)
				save_setting fon private encryption "$FORM_auth"
				save_setting fon private wpa_crypto "$FORM_crypto"
				save_setting fon private password "$FORM_psk"
			;;
			wep)
				save_setting fon private encryption wep
				save_setting fon private wepkey "$FORM_wepkey"
				save_setting fon private key1 "$FORM_key1"
				save_setting fon private key2 "$FORM_key2"
				save_setting fon private key3 "$FORM_key3"
				save_setting fon private key4 "$FORM_key4"
			;;
			*)
				save_setting fon private encryption open
			;;
		esac
			if [ "$FORM_mode" != "wlan" ]; then
validate <<EOF
chk_bgmode|FORM_bgmode|@TR<<BGMode#b/g Mode>>|required|$FORM_bgmode
chk_channel|FORM_channel|@TR<<Channel>>|required|$FORM_channel
EOF
equal "$?" 0 && {
	save_setting fon advanced bgmode "$FORM_bgmode"
	save_setting fon advanced channel "$FORM_channel"
	commit_settings
	(
		ifconfig ath0 down
		ifconfig ath1 down
		ifup lan
		ifconfig ath0 up
	) >/dev/null 2>/dev/null &
	}
			fi
		commit_settings
		SAVED=1
	}
}
fi

if [ "$FORM_mode" != "wlan" ]; then
channels=
for ch in $(iwlist ath1 freq | grep 'Channel ' | grep -v "reque" | awk '{print $2}'); do
	channels="${channels:+$channels$N}option|$ch|$ch"
done

#fallback
channels="${channels:-
option|01|01
option|02|02
option|03|03
option|04|04
option|05|05
option|06|06
option|07|07
option|08|08
option|09|09
option|10|10
option|11|11}"
fi

header "Priv_Title#Private Wireless Settings"

if [ "$SAVED" = "1" ]; then
	echo "<br /><br /><font color=red><b>EXECUTING CONFIGURATION</b></font>"
fi

cat <<EOF
<script type="text/javascript">
<!--
function modechange() {
	var v = isset('auth', 'wpa') || isset('auth', 'wpa2') || isset('auth', 'mixed');
	set_visible('wpa_stuff', v);
	set_visible('wep_stuff', isset('auth', 'wep'));
}
-->
</script>
EOF

display_form <<EOF
	infotable|PRE_PRIV_SSID#This is the name of the signal for your personal use.
	start_table|0|10|5
		add_row
			add_label_cell|@TR<<SSID#Name (SSID)>>
			add_input_cell|ssid|$FORM_ssid|tableTextButton
		end_row
		add_row
			add_label_cell|@TR<<Hide SSID>>
			start_select_cell|hide_ssid|$FORM_hide_ssid|tableTextSelect
				option|0|@TR<<No>>
				option|1|@TR<<Yes>>
			end_select_cell
		end_row
EOF
	[ $FORM_mode != "wlan" ] && {
display_form <<EOF
		add_row
			add_label_cell|@TR<<Bridge WAN and Private>>
			start_select_cell|bridge|$FORM_bridge|tableTextSelect
				option|0|@TR<<No>>
				option|1|@TR<<Yes>>
			end_select_cell
		end_row
EOF
	}
display_form <<EOF
		onchange|modechange
		add_row
			add_label_cell|@TR<<Authentication>>
			start_select_cell|auth|$FORM_auth|tableTextSelect
				option|open|@TR<<None>>
				option|wep|WEP
				option|wpa|WPA
				option|wpa2|WPA2
				option|mixed|@TR<<WPA and WPA2>>
			end_select_cell
		end_row
	end_table

	start_div|wpa_stuff
		start_table|0|10|5
			add_row
				add_label_cell|@TR<<Cipher>>
				start_select_cell|crypto|$FORM_crypto|tableTextSelect
					option|tkip+aes|@TR<<TKIP and AES>>
					option|tkip|TKIP
					option|aes|AES
				end_select_cell
			end_row
			add_row
				add_label_cell|@TR<<WPA Passphrase>>
				add_input_cell|psk|$FORM_psk|tableTextButton
			end_row
		end_table
	end_div

	start_div|wep_stuff
		start_table|0|10|5
			add_row
				add_label_cell|@TR<<Use key>>
				start_select_cell|wepkey|$FORM_wepkey|tableTextSelect
					option|1|1
					option|2|2
					option|3|3
					option|4|4
				end_select_cell
			end_row
			add_row
				add_label_cell|@TR<<WEP Key>> 1
				add_input_cell|key1|$FORM_key1|tableTextButton
			end_row
			add_row
				add_label_cell|@TR<<WEP Key>> 2
				add_input_cell|key2|$FORM_key2|tableTextButton
			end_row
			add_row
				add_label_cell|@TR<<WEP Key>> 3
				add_input_cell|key3|$FORM_key3|tableTextButton
			end_row
			add_row
				add_label_cell|@TR<<WEP Key>> 4
				add_input_cell|key4|$FORM_key4|tableTextButton
			end_row
		end_table
	end_div
#	start_table|0|10|5
#			add_row
#				add_label_cell|@TR<<TX Power>>
#				start_select_cell|txp|$FORM_txp|tableTextSelect
#					option|18|18 dBm (63 mW)
#					option|16|16 dBm (39 mW)
#					option|14|14 dBm (25 mW)
#					option|12|12 dBm (15 mW)
#					option|10|10 dBm (10 mW)
#					option|8|8 dBm (6 mW)
#					option|6|6 dBm (3 mW)
#					option|0|0 dBm (1 mW)
#			end_row
#	end_table
	start_table|0|10|5
		add_row
			add_button_cell|submit|@TR<<Submit>>
		end_row
	end_table
	call_js|modechange
EOF

if [ "$FORM_mode" != "wlan" ]; then
display_form <<EOF
	infotable|Advanced_wifi#This values will permit you configure very specific WiFi paramters of La Fonera. All of them are optional
	start_table|0|10|5
		add_row
			add_label_cell|@TR<<Channel>>
			start_select_cell|channel|$FORM_channel|tableTextSelect
				option|auto|@TR<<Automatic>>
				$channels
			end_select_cell
		end_row
		add_row
			add_label_cell|@TR<<BGMode#b/g Mode>>
			start_select_cell|bgmode|$FORM_bgmode|tableTextSelect
				option|mixed|@TR<<b and g>>
				option|g|@TR<<g only>>
				option|b|@TR<<b only>>
			end_select_cell
		end_row
		add_row
			add_button_cell|submit|@TR<<Submit>>|tableTextButton
		end_row
	end_table
EOF
fi

footer

if [ "$SAVED" = "1" ]; then
SAVED=0
display_form <<EOF
	autoloadpage|private|services
EOF
	sleep 2
	lock -u /var/run/restart-services
	lock -u /var/run/network-connection
fi;

?>